=======
History
=======

0.1.0 (2018-06-12)
------------------

* First release on PyPI.

0.5.0 (2019-10-17)
------------------
Unfortunately we did not save history for previous versions. New features include:

* AutoZI & TotalVI
* Tests for LDVAE notebook
* Add how to load CITE-SEQ data on dataloading notebook
* Made the intro tutorial more user friendly
* Removed requirements.txt and rely only on setup.py


